#pragma once
#include <cstdint>

namespace signiamge::c_wrapper {

struct RGBAColor {
    uint8_t r = 0;
    uint8_t g = 0;
    uint8_t b = 0;
    uint8_t alpha = 0xff;
};

struct XY {
    double x = 0;
    double y = 0;
};

struct Resolution {
    uint64_t width = 0;
    uint64_t height = 0;
};

struct BorderRadius {
    double cornerWidth = 0;
    double cornerHeight = 0;
};

struct Size {
    double width = 0;
    double height = 0;
};

enum TextAlignment {
    UndefinedGravity,
    ForgetGravity = 0,
    NorthWestGravity = 1,
    NorthGravity = 2,
    NorthEastGravity = 3,
    WestGravity = 4,
    CenterGravity = 5,
    EastGravity = 6,
    SouthWestGravity = 7,
    SouthGravity = 8
};

enum ColorModel : uint8_t { RGB, RGBA };

struct Params {
    RGBAColor bg_color;
    RGBAColor text_color;
    RGBAColor border_color;
    BorderRadius border_radius;
    Size signature_size;
    uint64_t title_font_size;
    uint64_t font_size;
    double right_margin = .015;
    uint64_t border_width;
    const char *font_family = "Noto Sans";
    const char *title = nullptr;
    const char *cert_serial = nullptr;
    const char *subject = nullptr;
    const char *time_validity = nullptr;
    unsigned char *ptr_logo_data = nullptr;
    uint64_t ptr_logo_size = 0;
    const char *ptr_logo_file = nullptr;
    XY logo_size_goal;
    bool logo_preserve_ratio = true;
    ColorModel color_model_out = RGB;
    XY logo_position;
    XY title_position;
    XY cert_serial_position;
    XY subject_position;
    XY time_validity_position;
    TextAlignment title_alignment;
    TextAlignment content_alignment;
};

struct Result {
    unsigned char *stamp_img_data = nullptr;
    uint64_t stamp_img_data_size = 0;
    Resolution resolution;
};

} // namespace signiamge::c_wrapper
